/*********************************************************************
*                    SEGGER Microcontroller GmbH                     *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2020  SEGGER Microcontroller GmbH                *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V6.10 - Graphical user interface for embedded applications **
emWin is protected by international copyright laws.   Knowledge of the
source code may not be used to write a similar product.  This file may
only  be used  in accordance  with  a license  and should  not be  re-
distributed in any way. We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : DIALOG_Keypad_Usage.c
Purpose     : Sample that demonstrates the usage of the sample
              keyboard dialog.
              Required files: GUI_Keypad.c and GUI_Keypad.h
Requirements: WindowManager - (x)
              MemoryDevices - ( )
              AntiAliasing  - ( )
              VNC-Server    - ( )
              PNG-Library   - ( )
              TrueTypeFonts - ( )
---------------------------END-OF-HEADER------------------------------
*/

#include "GUI_Keypad.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
static void _cbWin(WM_MESSAGE * pMsg) {
  WM_MESSAGE     Message;
  static WM_HWIN hKeypad;
  int            Id, NCode;
  WM_HWIN        hItem;
  char           acBuffer[64];

  switch(pMsg->MsgId) {
  case WM_CREATE:
    //
    // Create keypad
    //
    hKeypad = GUI_CreateKeyPad(pMsg->hWin);
    //
    // Create TEXT widget
    //
    TEXT_CreateEx(10, 10, 80, 20, pMsg->hWin, WM_CF_SHOW, 0, GUI_ID_TEXT0, "");
    //
    // Create EDIT widget
    //
    EDIT_CreateEx(10, 40, 80, 20, pMsg->hWin, WM_CF_SHOW, 0, GUI_ID_EDIT0, 64);
    //
    // Create OK button
    //
    hItem = BUTTON_CreateEx(100, 35, 30, 30, pMsg->hWin, WM_CF_SHOW, 0, GUI_ID_BUTTON0);
    BUTTON_SetText(hItem, "OK");
    break;
  case WM_PAINT:
    GUI_SetBkColor(GUI_WHITE);
    GUI_Clear();
    break;
  case WM_NOTIFY_PARENT:
    Id    = WM_GetId(pMsg->hWinSrc);
    NCode = pMsg->Data.v;
    switch(Id) {
    case GUI_ID_BUTTON0:
      switch(NCode) {
      case WM_NOTIFICATION_CLICKED:
        break;
      case WM_NOTIFICATION_RELEASED:
        //
        // Copy text over to TEXT widget and clear EDIT.
        //
        hItem = WM_GetDialogItem(pMsg->hWin, GUI_ID_EDIT0);
        EDIT_GetText(hItem, acBuffer, sizeof(acBuffer));
        EDIT_SetText(hItem, "");
        hItem = WM_GetDialogItem(pMsg->hWin, GUI_ID_TEXT0);
        TEXT_SetText(hItem, acBuffer);
        //
        // Send message with 0 as parameter to close keyboard.
        //
        Message.Data.v  = 0;
        Message.hWin    = hKeypad;
        Message.hWinSrc = pMsg->hWin;
        Message.MsgId   = MSG_ANIMATE;
        WM_SendMessage(hKeypad, &Message);
        break;
      }
      break;
    case GUI_ID_EDIT0:
      switch(NCode) {
      case WM_NOTIFICATION_CLICKED:
        break;
      case WM_NOTIFICATION_RELEASED:
        //
        // Send message with 1 as parameter to open keyboard.
        //
        Message.Data.v  = 1;
        Message.hWin    = hKeypad;
        Message.hWinSrc = pMsg->hWin;
        Message.MsgId   = MSG_ANIMATE;
        WM_SendMessage(hKeypad, &Message);
        break;
      }
      break;
    }
    break;
  default:
    WM_DefaultProc(pMsg);
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  //
  // Init emWin.
  //
  GUI_Init();
  WM_MULTIBUF_Enable(1);
  //
  // Create window.
  //
  WM_CreateWindow(0, 0, LCD_GetXSize(), LCD_GetYSize(), WM_CF_SHOW, _cbWin, 0);

  while (1) {
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/
